==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SubjectAccessReviewStatusFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface SubjectAccessReviewStatusFluent<A extends SubjectAccessReviewStatusFluent<A>> extends Fluent<A> {


    public Boolean getAllowed();
    public A withAllowed(Boolean allowed);
    public Boolean hasAllowed();
    public A withNewAllowed(String arg1);
    public A withNewAllowed(boolean arg1);
    public Boolean getDenied();
    public A withDenied(Boolean denied);
    public Boolean hasDenied();
    public A withNewDenied(String arg1);
    public A withNewDenied(boolean arg1);
    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public A withNewEvaluationError(StringBuilder arg1);
    public A withNewEvaluationError(int[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(char[] arg1);
    public A withNewEvaluationError(StringBuffer arg1);
    public A withNewEvaluationError(byte[] arg1,int arg2);
    public A withNewEvaluationError(byte[] arg1);
    public A withNewEvaluationError(char[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewEvaluationError(String arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(int[] arg1,int arg2,int arg3);
    public A withNewReason(char[] arg1);
    public A withNewReason(StringBuffer arg1);
    public A withNewReason(byte[] arg1,int arg2);
    public A withNewReason(byte[] arg1);
    public A withNewReason(char[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReason(String arg1);
}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SubjectAccessReviewStatusFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface SubjectAccessReviewStatusFluent<A extends SubjectAccessReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Boolean getAllowed();
    public A withAllowed(Boolean allowed);
    public Boolean hasAllowed();
    public A withNewAllowed(String arg1);
    public A withNewAllowed(boolean arg1);
    public Boolean getDenied();
    public A withDenied(Boolean denied);
    public Boolean hasDenied();
    public A withNewDenied(String arg1);
    public A withNewDenied(boolean arg1);
    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public A withNewEvaluationError(StringBuilder arg1);
    public A withNewEvaluationError(int[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(char[] arg1);
    public A withNewEvaluationError(StringBuffer arg1);
    public A withNewEvaluationError(byte[] arg1,int arg2);
    public A withNewEvaluationError(byte[] arg1);
    public A withNewEvaluationError(char[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewEvaluationError(String arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(int[] arg1,int arg2,int arg3);
    public A withNewReason(char[] arg1);
    public A withNewReason(StringBuffer arg1);
    public A withNewReason(byte[] arg1,int arg2);
    public A withNewReason(byte[] arg1);
    public A withNewReason(char[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3);
    public A withNewReason(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReason(String arg1);
}
